// NMDropTarget.cpp :  Դϴ.
//

#include "stdafx.h"
#include "NMDropTarget.h"
#include "ChatDlg.h"
#include "SMSSendWnd.h"

// CNMDropTarget

CNMDropTarget::CNMDropTarget()
: m_pChatDialog(NULL),m_pSmsSendWnd(NULL)
{
	_clipBoardFormat = RegisterClipboardFormat(_T("CF_NTALK_ID"));
}

CNMDropTarget::~CNMDropTarget()
{
}


BOOL CNMDropTarget::OnDrop(CWnd* pWnd, COleDataObject* pDataObject,	DROPEFFECT dropEffect, CPoint point){

  ASSERT((m_pSmsSendWnd== NULL || m_pChatDialog== NULL));
  if (m_pSmsSendWnd == NULL)
  {
     return OnDropToChatDlg(pWnd,pDataObject,dropEffect,point);
  } 
  else
  {
	  return OnDropToSmsDlg(pWnd,pDataObject,dropEffect,point);

  }
}

BOOL CNMDropTarget::OnDropToSmsDlg(CWnd* pWnd, COleDataObject* pDataObject,	DROPEFFECT dropEffect, CPoint point)
{
	//BOOL bRet = TRUE;
	
	if (pDataObject->IsDataAvailable(_clipBoardFormat))
	{
		try
		{
			CFile* pFile = pDataObject->GetFileData(_clipBoardFormat);
			if (pFile == NULL) return TRUE;

			CArchive ar(pFile, CArchive::load); 
			int nCount = -1;
			ar >> nCount;

			//FIX:NTALKCL-1274 && NTALKCK-1275-BUG2
			std::vector<CNtalkDragData*> DragDropUsers;
			std::vector<CNtalkDragData*> dropUsersToSms;
            m_pSmsSendWnd->InitializeMsgPopOnce();  			
			for (int i = 0; i < nCount; ++i)
			{
				CNtalkDragData* dropUser = new CNtalkDragData();
				dropUser->Serialize(ar); 
				DragDropUsers.push_back(dropUser);
				if (m_pSmsSendWnd->AddSMSReceiver( dropUser->m_strID,dropUser->m_strName, dropUser->m_strCellphone))
				{
                   dropUsersToSms.push_back(dropUser);
				}				
			}

			if (dropUsersToSms.size() > 0)  //The list UI should be updated when the drop users vector is not empty. NTALKCK-1275-BUG2
			{
                m_pSmsSendWnd->RefreshListBeforeOp();
				for (int i = 0; i < dropUsersToSms.size(); ++i)
				{
                    CNtalkDragData *pDropUser = dropUsersToSms[i];
                     m_pSmsSendWnd->AddSMSReceiverNode(pDropUser->m_strID,pDropUser->m_strName, pDropUser->m_strCellphone);
				}	

                m_pSmsSendWnd->RefreshListAfterOp();
			}
			for (int i = 0; i < DragDropUsers.size(); ++i) //Delete all CNtalkDragData memory.
			{
				CNtalkDragData *pDropUser = DragDropUsers[i];				
				delete(pDropUser);
			}	

			ar.Close();
			delete pFile;
		  
			return TRUE;
						

		}
		catch (CException* pEx)
		{
			NTALK_LOG->Error(L"BOOL CNMDropTarget::OnDrop(CWnd* pWnd, COleDataObject* pDataObject,	DROPEFFECT dropEffect, CPoint point)");
			NTALK_LOG->Error("%s %d\n", __FUNCTION__, __LINE__);
			pEx->ReportError();
			pEx->Delete();
			return FALSE;
		}
	}

	return COleDropTarget::OnDrop(pWnd, pDataObject, dropEffect, point);
}


BOOL CNMDropTarget::OnDropToChatDlg(CWnd* pWnd, COleDataObject* pDataObject,	DROPEFFECT dropEffect, CPoint point)
{
	BOOL bRet = TRUE;
	if (pDataObject->IsDataAvailable(CF_HDROP))
	{
		STGMEDIUM stgMed;
		FORMATETC fmte = { CF_HDROP, (DVTARGETDEVICE FAR*)NULL, DVASPECT_CONTENT, -1, TYMED_HGLOBAL };
		if (pDataObject->GetData(CF_HDROP, &stgMed, &fmte))
		{
			HDROP hDrop = (HDROP)stgMed.hGlobal;

			UINT nCntFiles = ::DragQueryFile(hDrop, (UINT)-1, NULL, 0);
			if (nCntFiles <= 0)
				return FALSE;

			TCHAR tszFile[MAX_PATH] = { 0 };
			std::vector<CString> attachFileVector;
			for (UINT ui = 0; ui < nCntFiles; ui++)
			{
				::DragQueryFile(hDrop, ui, tszFile, _countof(tszFile));
				attachFileVector.push_back(tszFile);
			}
			m_pChatDialog->SetSendFile(attachFileVector);
		}

		return bRet;
	}

	if (pDataObject->IsDataAvailable(_clipBoardFormat))
	{
		try
		{
			CFile* pFile = pDataObject->GetFileData(_clipBoardFormat);
			if (pFile == NULL) return TRUE;

			CArchive ar(pFile, CArchive::load); 
			int nCount = -1;

			ar >> nCount;

			std::vector<CChatUser *> dropUsers;
			bool bOffline = false;

			for (int i = 0; i < nCount; ++i)
			{
				CNtalkDragData dropUser;
				dropUser.Serialize(ar);

				TRACE("%s %d %s %d\n", __FUNCTION__, __LINE__, dropUser.m_strID, dropUser.m_nUserStatus);

				// °  ƴ  츸 ߰
		        int dropUserSts = dropUser.m_nUserStatus/* & (~ustMOBILE)*/;
				if (dropUserSts != ustOFFLINE)
				{
					CChatUser* pChatUser = new CChatUser();
					if (NULL != pChatUser)
					{
						pChatUser->SetDragData(dropUser);
						dropUsers.push_back(pChatUser);
					}
				}else
				{
					bOffline = true;
				}
			}
			ar.Close();
			delete pFile;

			if(bOffline)
			{
				m_pChatDialog->AlertOfflineUser();
			}
			
			if(m_pChatDialog->IsEnableDragAndDrop() == TRUE)
			{
				BOOL status = m_pChatDialog->AddChatUserList(dropUsers);
		    	FTLASSERT(status);
				//m_pChatDialog->AddChatUserList(dropUsers);
				vector<CChatUser*>::iterator itr = dropUsers.begin();
				return TRUE;
			}
			else
			{
				NTALK_LOG->Debug(L"BOOL CNMDropTarget::OnDrop():m_pChatDialog->IsEnableDragAndDrop() == false\n");
				vector<CChatUser*>::iterator itr = dropUsers.begin();
				for (; itr != dropUsers.end(); itr++)
				{
					delete (*itr);
				}
				return FALSE;
			}
			
		}
		catch (CException* pEx)
		{
			NTALK_LOG->Error(L"BOOL CNMDropTarget::OnDrop(CWnd* pWnd, COleDataObject* pDataObject,	DROPEFFECT dropEffect, CPoint point)");
	        NTALK_LOG->Error("%s %d\n", __FUNCTION__, __LINE__);
		    pEx->ReportError();
			pEx->Delete();
			return FALSE;
		}

	}

	return COleDropTarget::OnDrop(pWnd, pDataObject, dropEffect, point);
}

DROPEFFECT CNMDropTarget::OnDragOver(CWnd* pWnd, COleDataObject* pDataObject, DWORD dwKeyState, CPoint point)
{
	return GetDropEffect(pDataObject);
}

DROPEFFECT CNMDropTarget::OnDragEnter(CWnd* pWnd, COleDataObject* pDataObject, DWORD dwKeyState, CPoint point)
{
	return GetDropEffect(pDataObject);
}

DROPEFFECT CNMDropTarget::GetDropEffect( COleDataObject* pDataObject )
{
	DROPEFFECT dropEffect = DROPEFFECT_NONE;

	if (pDataObject->IsDataAvailable(CF_HDROP))
	{
		dropEffect = DROPEFFECT_COPY;
	}
	if (pDataObject->IsDataAvailable(_clipBoardFormat))
	{
		try{
			CFile* pFile = pDataObject->GetFileData(_clipBoardFormat);
			if (pFile == NULL) return TRUE;

			CArchive ar(pFile, CArchive::load); 
			int nCount = -1;

			ar >> nCount;
			if (nCount > 0)
			{
				dropEffect = DROPEFFECT_COPY;
			}

			ar.Close();
			delete pFile;
		}
		

		catch (CException* pEx)
		{
			NTALK_LOG->Error(L"BOOL CNMDropTarget::OnDrop(CWnd* pWnd, COleDataObject* pDataObject,	DROPEFFECT dropEffect, CPoint point)");
			NTALK_LOG->Error("%s %d\n", __FUNCTION__, __LINE__);
			pEx->ReportError();
			pEx->Delete();
			return FALSE;
		}
	}

	return dropEffect;
}

void CNMDropTarget::SetChatDialog(CChatDlg * pDialog )
{
	m_pChatDialog = pDialog;
}

void CNMDropTarget::SetSMSSendDlg(CSMSSendWnd * pWnd )
{
	m_pSmsSendWnd = pWnd;
}
